@@ -10,13 +10,13 @@ set.seed(1234)
 
 
 ###################################################
-### code chunk number 2: recommenderlab.Rnw:1056-1057
+### code chunk number 2: recommenderlab.Rnw:1058-1059
 ###################################################
 library("recommenderlab")
 
 
 ###################################################
-### code chunk number 3: recommenderlab.Rnw:1065-1070
+### code chunk number 3: recommenderlab.Rnw:1067-1072
 ###################################################
 m <- matrix(sample(c(as.numeric(0:5), NA), 50, 
     replace=TRUE, prob=c(rep(.4/6,6),.6)), ncol=10,
@@ -26,7 +26,7 @@ m
 
 
 ###################################################
-### code chunk number 4: recommenderlab.Rnw:1077-1080
+### code chunk number 4: recommenderlab.Rnw:1079-1082
 ###################################################
 r <- as(m, "realRatingMatrix")
 r
@@ -34,27 +34,27 @@ r
 
 
 ###################################################
-### code chunk number 5: recommenderlab.Rnw:1085-1086
+### code chunk number 5: recommenderlab.Rnw:1087-1088
 ###################################################
 identical(as(r, "matrix"),m)
 
 
 ###################################################
-### code chunk number 6: recommenderlab.Rnw:1094-1096
+### code chunk number 6: recommenderlab.Rnw:1096-1098
 ###################################################
 as(r, "list")
 head(as(r, "data.frame"))
 
 
 ###################################################
-### code chunk number 7: recommenderlab.Rnw:1109-1111
+### code chunk number 7: recommenderlab.Rnw:1111-1113
 ###################################################
 r_m <- normalize(r)
 r_m
 
 
 ###################################################
-### code chunk number 8: recommenderlab.Rnw:1117-1119 (eval = FALSE)
+### code chunk number 8: recommenderlab.Rnw:1119-1121 (eval = FALSE)
 ###################################################
 ## image(r, main = "Raw Ratings")
 ## image(r_m, main = "Normalized Ratings")
@@ -73,28 +73,28 @@ print(image(r_m, main = "Normalized Ratings"))
 
 
 ###################################################
-### code chunk number 11: recommenderlab.Rnw:1152-1154
+### code chunk number 11: recommenderlab.Rnw:1154-1156
 ###################################################
 r_b <- binarize(r, minRating=4)
 as(r_b, "matrix")
 
 
 ###################################################
-### code chunk number 12: recommenderlab.Rnw:1166-1168
+### code chunk number 12: recommenderlab.Rnw:1168-1170
 ###################################################
 data(Jester5k)
 Jester5k
 
 
 ###################################################
-### code chunk number 13: recommenderlab.Rnw:1176-1178
+### code chunk number 13: recommenderlab.Rnw:1178-1180
 ###################################################
 r <- sample(Jester5k, 1000) 
 r
 
 
 ###################################################
-### code chunk number 14: recommenderlab.Rnw:1185-1188
+### code chunk number 14: recommenderlab.Rnw:1187-1190
 ###################################################
 rowCounts(r[1,])
 as(r[1,], "list")
@@ -132,40 +132,40 @@ hist(colMeans(r), breaks=20)
 
 
 ###################################################
-### code chunk number 20: recommenderlab.Rnw:1275-1276
+### code chunk number 20: recommenderlab.Rnw:1277-1278
 ###################################################
 recommenderRegistry$get_entries(dataType = "realRatingMatrix")
 
 
 ###################################################
-### code chunk number 21: recommenderlab.Rnw:1284-1286
+### code chunk number 21: recommenderlab.Rnw:1286-1288
 ###################################################
 r <- Recommender(Jester5k[1:1000], method = "POPULAR")
 r
 
 
 ###################################################
-### code chunk number 22: recommenderlab.Rnw:1290-1292
+### code chunk number 22: recommenderlab.Rnw:1292-1294
 ###################################################
 names(getModel(r))
 getModel(r)$topN
 
 
 ###################################################
-### code chunk number 23: recommenderlab.Rnw:1307-1309
+### code chunk number 23: recommenderlab.Rnw:1309-1311
 ###################################################
 recom <- predict(r, Jester5k[1001:1002], n=5)
 recom
 
 
 ###################################################
-### code chunk number 24: recommenderlab.Rnw:1314-1315
+### code chunk number 24: recommenderlab.Rnw:1316-1317
 ###################################################
 as(recom, "list")
 
 
 ###################################################
-### code chunk number 25: recommenderlab.Rnw:1321-1324
+### code chunk number 25: recommenderlab.Rnw:1323-1326
 ###################################################
 recom3 <- bestN(recom, n = 3)
 recom3
@@ -173,7 +173,7 @@ as(recom3, "list")
 
 
 ###################################################
-### code chunk number 26: recommenderlab.Rnw:1332-1335
+### code chunk number 26: recommenderlab.Rnw:1334-1337
 ###################################################
 recom <- predict(r, Jester5k[1001:1002], type="ratings")
 recom
@@ -181,7 +181,7 @@ as(recom, "matrix")[,1:10]
 
 
 ###################################################
-### code chunk number 27: recommenderlab.Rnw:1355-1358
+### code chunk number 27: recommenderlab.Rnw:1357-1360
 ###################################################
 e <- evaluationScheme(Jester5k[1:1000], method="split", train=0.9, 
     given=15, goodRating=5)
@@ -189,7 +189,7 @@ e
 
 
 ###################################################
-### code chunk number 28: recommenderlab.Rnw:1364-1369
+### code chunk number 28: recommenderlab.Rnw:1366-1371
 ###################################################
 r1 <- Recommender(getData(e, "train"), "UBCF")
 r1
@@ -199,7 +199,7 @@ r2
 
 
 ###################################################
-### code chunk number 29: recommenderlab.Rnw:1376-1380
+### code chunk number 29: recommenderlab.Rnw:1378-1382
 ###################################################
 p1 <- predict(r1, getData(e, "known"), type="ratings")
 p1
@@ -208,7 +208,7 @@ p2
 
 
 ###################################################
-### code chunk number 30: recommenderlab.Rnw:1386-1392
+### code chunk number 30: recommenderlab.Rnw:1388-1394
 ###################################################
 error <- rbind(
   calcPredictionAccuracy(p1, getData(e, "unknown")),
@@ -219,7 +219,7 @@ error
 
 
 ###################################################
-### code chunk number 31: recommenderlab.Rnw:1405-1408
+### code chunk number 31: recommenderlab.Rnw:1407-1410
 ###################################################
 scheme <- evaluationScheme(Jester5k[1:1000], method="cross", k=4, given=3,
     goodRating=5)
@@ -227,20 +227,21 @@ scheme
 
 
 ###################################################
-### code chunk number 32: recommenderlab.Rnw:1415-1417
+### code chunk number 32: recommenderlab.Rnw:1417-1420
 ###################################################
-results <- evaluate(scheme, method="POPULAR", n=c(1,3,5,10,15,20))
+results <- evaluate(scheme, method="POPULAR", type = "topNList", 
+  n=c(1,3,5,10,15,20))
 results
 
 
 ###################################################
-### code chunk number 33: recommenderlab.Rnw:1428-1429
+### code chunk number 33: recommenderlab.Rnw:1431-1432
 ###################################################
 getConfusionMatrix(results)[[1]]
 
 
 ###################################################
-### code chunk number 34: recommenderlab.Rnw:1441-1442
+### code chunk number 34: recommenderlab.Rnw:1444-1445
 ###################################################
 avg(results)
 
@@ -258,31 +259,34 @@ plot(results, "prec/rec", annotate=TRUE)
 
 
 ###################################################
-### code chunk number 37: recommenderlab.Rnw:1487-1500
+### code chunk number 37: recommenderlab.Rnw:1491-1507
 ###################################################
+set.seed(2016)
 scheme <- evaluationScheme(Jester5k[1:1000], method="split", train = .9, 
-    k=1, given=20, goodRating=5)
+  k=1, given=-5, goodRating=5)
 scheme
 
 algorithms <- list(
-        "random items" = list(name="RANDOM", param=NULL),
-        "popular items" = list(name="POPULAR", param=NULL),
-        "user-based CF" = list(name="UBCF", param=list(method="Cosine", 
-		nn=50, minRating=5))
-        )
+  "random items" = list(name="RANDOM", param=NULL),
+  "popular items" = list(name="POPULAR", param=NULL),
+  "user-based CF" = list(name="UBCF", param=list(nn=50)),
+  "item-based CF" = list(name="IBCF", param=list(k=50)),
+  "SVD approximation" = list(name="SVD", param=list(approxRank = 50))
+)
 
 ## run algorithms
-results <- evaluate(scheme, algorithms, n=c(1, 3, 5, 10, 15, 20))
+results <- evaluate(scheme, algorithms, type = "topNList", 
+  n=c(1, 3, 5, 10, 15, 20))
 
 
 ###################################################
-### code chunk number 38: recommenderlab.Rnw:1505-1506
+### code chunk number 38: recommenderlab.Rnw:1512-1513
 ###################################################
 results
 
 
 ###################################################
-### code chunk number 39: recommenderlab.Rnw:1512-1514
+### code chunk number 39: recommenderlab.Rnw:1519-1521
 ###################################################
 names(results)
 results[["user-based CF"]]
@@ -291,40 +295,54 @@ results[["user-based CF"]]
 ###################################################
 ### code chunk number 40: roc2
 ###################################################
-plot(results, annotate=c(1,3), legend="topleft")
+plot(results, annotate=c(1,3), legend="bottomright")
 
 
 ###################################################
 ### code chunk number 41: precrec2
 ###################################################
-plot(results, "prec/rec", annotate=3)
+plot(results, "prec/rec", annotate=3, legend="topleft")
 
 
 ###################################################
-### code chunk number 42: recommenderlab.Rnw:1555-1567
+### code chunk number 42: recommenderlab.Rnw:1564-1566
+###################################################
+## run algorithms
+results <- evaluate(scheme, algorithms, type = "ratings") 
+
+
+###################################################
+### code chunk number 43: recommenderlab.Rnw:1571-1572
+###################################################
+results
+
+
+###################################################
+### code chunk number 44: real
+###################################################
+plot(results, ylim = c(0,100))
+
+
+###################################################
+### code chunk number 45: recommenderlab.Rnw:1595-1601
 ###################################################
 Jester_binary <- binarize(Jester5k, minRating=5)
 Jester_binary <- Jester_binary[rowCounts(Jester_binary)>20]
 Jester_binary
 scheme_binary <- evaluationScheme(Jester_binary[1:1000], 
-	method="split", train=.9, k=1, given=20)
+	method="split", train=.9, k=1, given=3)
 scheme_binary
 
-algorithms_binary <- list(
-        "random items" = list(name="RANDOM", param=NULL),
-        "popular items" = list(name="POPULAR", param=NULL),
-        "user-based CF" = list(name="UBCF", param=list(method="Jaccard", nn=50))
-        )
+
+###################################################
+### code chunk number 46: recommenderlab.Rnw:1604-1606
+###################################################
+results_binary <- evaluate(scheme_binary, algorithms, 
+  type = "topNList", n=c(1,3,5,10,15,20))
 
 
 ###################################################
-### code chunk number 43: recommenderlab.Rnw:1570-1571
-###################################################
-results_binary <- evaluate(scheme_binary, algorithms_binary, n=c(1,3,5,10,15,20))
-
-
-###################################################
-### code chunk number 44: roc3
+### code chunk number 47: roc3
 ###################################################
 plot(results_binary, annotate=c(1,3), legend="bottomright")
 
